@@ -7,6 +7,7 @@ import functools
 import hashlib
 import json
 import os
+import platform as _platform
 import subprocess
 import sys
 import time
@@ -93,9 +94,9 @@ def clone(
     if location is not None:
         cmd.append(location)
     try:
-        subprocess.call(cmd)
-    except Exception as e:
-        raise_error(str(e))
+        subprocess.check_call(cmd)
+    except subprocess.CalledProcessError:
+        raise_error("Failed to clone with Git")
     if location is None:
         location = url.split("/")[-1].removesuffix(".git")
     typer.echo(f"Moving into repo dir: {location}")
@@ -109,7 +110,10 @@ def clone(
                 calkit.dvc.set_remote_auth(remote_name=name)
     # DVC pull
     if not no_dvc_pull:
-        subprocess.call(["dvc", "pull"])
+        try:
+            subprocess.check_call(["dvc", "pull"])
+        except subprocess.CalledProcessError:
+            raise_error("Failed to pull from DVC remote(s)")
 
 
 @app.command(name="status")
@@ -654,7 +658,6 @@ def run_in_env(
         except subprocess.CalledProcessError:
             raise_error(f"Failed to run in {env['kind']} environment")
     elif env["kind"] == "uv-venv":
-        # TODO: This doesn't work on Windows
         if "prefix" not in env:
             raise_error("uv-venv environments require a prefix")
         if "path" not in env:
@@ -673,8 +676,12 @@ def run_in_env(
                     raise_error(f"Failed to create uv-venv at {prefix}")
             fname, ext = os.path.splitext(path)
             lock_fpath = fname + "-lock" + ext
+            if _platform.system() == "Windows":
+                activate_cmd = f"{prefix}\\Scripts\\activate"
+            else:
+                activate_cmd = f". {prefix}/bin/activate"
             check_cmd = (
-                f". {prefix}/bin/activate "
+                f"{activate_cmd} "
                 f"&& uv pip install -q -r {path} "
                 f"&& uv pip freeze > {lock_fpath} "
                 "&& deactivate"
@@ -686,7 +693,7 @@ def run_in_env(
             except subprocess.CalledProcessError:
                 raise_error("Failed to check uv-venv")
         # Now run the command
-        cmd = f". {prefix}/bin/activate && {shell_cmd} && deactivate"
+        cmd = f"{activate_cmd} && {shell_cmd} && deactivate"
         if verbose:
             typer.echo(f"Running command: {cmd}")
         try:
