@@ -89,6 +89,23 @@ def test_run_in_env(tmp_dir):
     ck_info = calkit.load_calkit_info()
     env = ck_info["environments"]["py3.10"]
     assert env.get("path") is None
+    # Test uv venv
+    subprocess.check_call(
+        ["calkit", "new", "uv-venv", "-n", "uv1", "polars==1.18.0"]
+    )
+    out = subprocess.check_output(
+        [
+            "calkit",
+            "runenv",
+            "-n",
+            "uv1",
+            "--",
+            "python",
+            "-c",
+            "'import polars; print(polars.__version__)'",
+        ]
+    ).decode().strip()
+    assert out == "1.18.0"
 
 
 def test_check_call():
